==> maven_3.5.4.orig.tar.xz: maven-maven-3.5.4/maven-compat/src/main/java/org/apache/maven/artifact/resolver/filter/TypeArtifactFilter.java <==
package org.apache.maven.artifact.resolver.filter;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.artifact.Artifact;

/** Artifact Filter which filters on artifact type */
public class TypeArtifactFilter
    implements ArtifactFilter
{
    private String type = "jar";

    public TypeArtifactFilter( String type )
    {
        this.type = type;
    }

    public boolean include( Artifact artifact )
    {
        return type.equals( artifact.getType() );
    }

    @Override
    public int hashCode()
    {
        int hash = 17;
        hash = hash * 31 + type.hashCode();
        return hash;
    }

    @Override
    public boolean equals( Object obj )
    {
        if ( this == obj )
        {
            return true;
        }

        if ( !( obj instanceof TypeArtifactFilter ) )
        {
            return false;
        }

        TypeArtifactFilter other = (TypeArtifactFilter) obj;

        return type.equals( other.type );
    }

}

==> maven_3.9.9.orig.tar.xz: maven-maven-3.9.9/maven-compat/src/main/java/org/apache/maven/artifact/resolver/filter/TypeArtifactFilter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.artifact.resolver.filter;

import org.apache.maven.artifact.Artifact;

/** Artifact Filter which filters on artifact type */
public class TypeArtifactFilter implements ArtifactFilter {
    private String type = "jar";

    public TypeArtifactFilter(String type) {
        this.type = type;
    }

    public boolean include(Artifact artifact) {
        return type.equals(artifact.getType());
    }

    @Override
    public int hashCode() {
        int hash = 17;
        hash = hash * 31 + type.hashCode();
        return hash;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }

        if (!(obj instanceof TypeArtifactFilter)) {
            return false;
        }

        TypeArtifactFilter other = (TypeArtifactFilter) obj;

        return type.equals(other.type);
    }
}
